@@ -7,6 +7,29 @@ from .items import WialonResource, WialonUnit
 from .session import WialonSession
 
 
+def get_hw_types(session: WialonSession) -> list[dict[str, str | int]]:
+    """
+    Returns a list of hardware type objects for Wialon.
+
+    :param session: A valid Wialon API session.
+    :type session: :py:obj:`~terminusgps.wialon.session.WialonSession`
+    :returns: A list of hardware types.
+    :rtype: :py:obj:`list`
+
+    Hardware type format:
+
+    +----------+--------------------+
+    | key      | value              |
+    +==========+====================+
+    | ``id``   | Hardware type id   |
+    +----------+--------------------+
+    | ``name`` | Hardware type name |
+    +----------+--------------------+
+
+    """
+    return session.wialon_api.core_get_hw_types()
+
+
 def get_user_by_name(name: str, session: WialonSession) -> WialonUnit | None:
     """
     Returns a Wialon user by name, if it exists.
@@ -133,8 +156,8 @@ def get_unit_by_iccid(iccid: str, session: WialonSession) -> WialonUnit | None:
             "to": 0,
         }
     )
-    if results:
-        return WialonUnit(id=results.get("items", [{}])[0].get("id"), session=session)
+    if results and results.get("totalItemsCount") == 1:
+        return WialonUnit(id=results["items"][0]["id"], session=session)
 
 
 def get_resources(session: WialonSession) -> list[WialonResource] | None:
@@ -228,8 +251,8 @@ def get_unit_by_imei(imei: str, session: WialonSession) -> WialonUnit | None:
         }
     )
 
-    if results is not None and results.get("totalItemsCount", 0) == 1:
-        return WialonUnit(id=results["items"][0].get("id"), session=session)
+    if results and results.get("totalItemsCount", 0) == 1:
+        return WialonUnit(id=results["items"][0]["id"], session=session)
 
 
 def get_vin_info(vin_number: str, session: WialonSession) -> dict[str, typing.Any]:
